fn numeric_cast_samples(scale: NumericMaxScale) -> Vec<Sample<UnaryFunc>>Expand description
The numeric casts, each without a scale (the primary record) and with one. Only the scaled cast can error, because it rounds.
fn numeric_cast_samples(scale: NumericMaxScale) -> Vec<Sample<UnaryFunc>>The numeric casts, each without a scale (the primary record) and with one. Only the scaled cast can error, because it rounds.